==> openrqm-1.0.3.tar.gz: test/rqm_document_test.dart <==
import 'package:openrqm/api.dart';
import 'package:test/test.dart';

// tests for RQMDocument
void main() {
    var instance = new RQMDocument();

  group('test RQMDocument', () {
    // int id (default value: null)
    test('to test the property `id`', () async {
      // TODO
    });

    // int workspaceId (default value: null)
    test('to test the property `workspaceId`', () async {
      // TODO
    });

    // int internalIdentifier (default value: null)
    test('to test the property `internalIdentifier`', () async {
      // TODO
    });

    // int externalIdentifier (default value: null)
    test('to test the property `externalIdentifier`', () async {
      // TODO
    });

    // String name (default value: null)
    test('to test the property `name`', () async {
      // TODO
    });

    // String shortName (default value: null)
    test('to test the property `shortName`', () async {
      // TODO
    });

    // String description (default value: null)
    test('to test the property `description`', () async {
      // TODO
    });

    // String confidentiality (default value: null)
    test('to test the property `confidentiality`', () async {
      // TODO
    });

    // int authorId (default value: null)
    test('to test the property `authorId`', () async {
      // TODO
    });

    // int languageId (default value: null)
    test('to test the property `languageId`', () async {
      // TODO
    });

    // int approverId (default value: null)
    test('to test the property `approverId`', () async {
      // TODO
    });

    // String reviewerText (default value: null)
    test('to test the property `reviewerText`', () async {
      // TODO
    });

    // int lastModifiedById (default value: null)
    test('to test the property `lastModifiedById`', () async {
      // TODO
    });

    // DateTime lastModifiedOn (default value: null)
    test('to test the property `lastModifiedOn`', () async {
      // TODO
    });

    // int baselineMajor (default value: null)
    test('to test the property `baselineMajor`', () async {
      // TODO
    });

    // int baselineMinor (default value: null)
    test('to test the property `baselineMinor`', () async {
      // TODO
    });

    // int baselineReview (default value: null)
    test('to test the property `baselineReview`', () async {
      // TODO
    });

    // int previousBaselineId (default value: null)
    test('to test the property `previousBaselineId`', () async {
      // TODO
    });


  });

}

==> openrqm-1.0.24.tar.gz: test/rqm_document_test.dart <==
import 'package:openrqm/api.dart';
import 'package:test/test.dart';

// tests for RQMDocument
void main() {
    var instance = new RQMDocument();

  group('test RQMDocument', () {
    // int id (default value: null)
    test('to test the property `id`', () async {
      // TODO
    });

    // int workspaceId (default value: null)
    test('to test the property `workspaceId`', () async {
      // TODO
    });

    // int internalIdentifier (default value: null)
    test('to test the property `internalIdentifier`', () async {
      // TODO
    });

    // String externalIdentifier (default value: null)
    test('to test the property `externalIdentifier`', () async {
      // TODO
    });

    // String name (default value: null)
    test('to test the property `name`', () async {
      // TODO
    });

    // String shortName (default value: null)
    test('to test the property `shortName`', () async {
      // TODO
    });

    // String description (default value: null)
    test('to test the property `description`', () async {
      // TODO
    });

    // String confidentiality (default value: null)
    test('to test the property `confidentiality`', () async {
      // TODO
    });

    // int authorId (default value: null)
    test('to test the property `authorId`', () async {
      // TODO
    });

    // int languageId (default value: null)
    test('to test the property `languageId`', () async {
      // TODO
    });

    // int approverId (default value: null)
    test('to test the property `approverId`', () async {
      // TODO
    });

    // String reviewerText (default value: null)
    test('to test the property `reviewerText`', () async {
      // TODO
    });

    // int lastModifiedById (default value: null)
    test('to test the property `lastModifiedById`', () async {
      // TODO
    });

    // DateTime lastModifiedOn (default value: null)
    test('to test the property `lastModifiedOn`', () async {
      // TODO
    });

    // int baselineMajor (default value: null)
    test('to test the property `baselineMajor`', () async {
      // TODO
    });

    // int baselineMinor (default value: null)
    test('to test the property `baselineMinor`', () async {
      // TODO
    });

    // int baselineReview (default value: null)
    test('to test the property `baselineReview`', () async {
      // TODO
    });

    // int previousBaselineId (default value: null)
    test('to test the property `previousBaselineId`', () async {
      // TODO
    });


  });

}
